@@ -1,7 +1,6 @@
 import django
 from django.conf import settings
 from django.forms.widgets import Select
-from django.contrib.admin.templatetags.admin_static import static
 from django.core.urlresolvers import reverse
 from django.utils.encoding import iri_to_uri
 from django.utils.safestring import mark_safe
@@ -17,23 +16,21 @@ else:
     USE_DJANGO_JQUERY = False
     JQUERY_URL = getattr(settings, 'JQUERY_URL', 'http://ajax.googleapis.com/ajax/libs/jquery/1.3.2/jquery.min.js')
 
-URL_PREFIX = getattr(settings, "SMART_SELECTS_URL_PREFIX", "")
 
 class ChainedSelect(Select):
-    def __init__(self, app_name, model_name, chain_field, model_field, show_all, auto_choose, manager=None, *args, **kwargs):
+    def __init__(self, app_name, model_name, chain_field, model_field, show_all, auto_choose, *args, **kwargs):
         self.app_name = app_name
         self.model_name = model_name
         self.chain_field = chain_field
         self.model_field = model_field
         self.show_all = show_all
         self.auto_choose = auto_choose
-        self.manager = manager
         super(Select, self).__init__(*args, **kwargs)
 
     class Media:
         if USE_DJANGO_JQUERY:
-            js = [static('admin/%s' % i) for i in
-                  ('js/jquery.min.js', 'js/jquery.init.js')]
+            js = ["%s%s" % (settings.ADMIN_MEDIA_PREFIX, i) for i in
+                    ('js/jquery.min.js', 'js/jquery.init.js')]
         elif JQUERY_URL:
             js = (
                 JQUERY_URL,
@@ -46,13 +43,9 @@ class ChainedSelect(Select):
             chain_field = self.chain_field
 
         if self.show_all:
-            view_name = "chained_filter_all"
+            url = "/".join(reverse("chained_filter_all", kwargs={'app':self.app_name, 'model':self.model_name, 'field':self.model_field, 'value':"1"}).split("/")[:-2])
         else:
-            view_name = "chained_filter"
-        kwargs = {'app':self.app_name, 'model':self.model_name, 'field':self.model_field, 'value':"1"}
-        if self.manager is not None:
-            kwargs.update({'manager': self.manager})
-        url = URL_PREFIX+("/".join(reverse(view_name, kwargs=kwargs).split("/")[:-2]))
+            url = "/".join(reverse("chained_filter", kwargs={'app':self.app_name, 'model':self.model_name, 'field':self.model_field, 'value':"1"}).split("/")[:-2])
         if self.auto_choose:
             auto_choose = 'true'
         else:
@@ -102,10 +95,7 @@ class ChainedSelect(Select):
                         for (var i = 0; i < j.length; i++) {
                             options += '<option value="' + j[i].value + '">' + j[i].display + '<'+'/option>';
                         }
-                        var width = $("#%(id)s").outerWidth();
                         $("#%(id)s").html(options);
-                        if (navigator.appVersion.indexOf("MSIE") != -1)
-                            $("#%(id)s").width(width + 'px');
                         $('#%(id)s option:first').attr('selected', 'selected');
                         var auto_choose = %(auto_choose)s;
                         if(init_value){
@@ -129,15 +119,6 @@ class ChainedSelect(Select):
                     fill_field(val, start_value);
                 })
             })
-            if (typeof(dismissAddAnotherPopup) !== 'undefined') {
-                var oldDismissAddAnotherPopup = dismissAddAnotherPopup;
-                dismissAddAnotherPopup = function(win, newId, newRepr) {
-                    oldDismissAddAnotherPopup(win, newId, newRepr);
-                    if (windowname_to_id(win.name) == "id_%(chainfield)s") {
-                        $("#id_%(chainfield)s").change();
-                    }
-                }
-            }
         })(jQuery || django.jQuery);
         //]]>
         </script>
